Two column data frame. The first column contains the name of the query and the second column contains information on the journal.
Arguments
query
Character vector to search for.
phrase
Logical. Should query be passed as a quoted phrase (e.g. "Journal of Zoology"). Default is FALSE.
sleep.time
Numeric. Time in seconds to sleep between query calls to the California Academy of Sciences page. This is set by default to 10 seconds, which is in their robots.txt. Adjust at your own risk.
verbose
Logical. Should query progress be messaged to the screen? Default is TRUE.
Author
Samuel R. Borstein
Details
This function returns information on the journals cited in the Eschmeyer's Catalog of Fishes.
References
Fricke, R. & Eschmeyer, W.N. (Year Accessed). Eschmeyer’s Catalog of Fishes: Journals. https://researcharchive.calacademy.org/research/ichthyology/catalog/journals.asp