#Note that for Windows OS, OpenSSL must be used as a backend for curl.
#Please see vignette on how to do this with vignette('rcatfish').
#Search for Abactochromis and return taxon history
if((.Platform$OS.type == "windows") & (grepl(pattern = "\\(OpenSSL",
curl::curl_version()$ssl_version) == TRUE)){
cat("openSSL backend for curl is required for the Windows version of this package, but it not
detected as being active. Please see the vignette on how to configure curl with openSSL for this
function to work. You can access the vignette with the following: vignette('rcatfish').")
}else{
my.search <- rcatfish_search(type = "Species", query = "Abactochromis",
taxon.history = FALSE, resolve = FALSE, sleep.time = 0)
}
#Search for the genera Astatheros and Gasteropelecidae
# \donttest{
if((.Platform$OS.type == "windows") & (grepl(pattern = "\\(OpenSSL",
curl::curl_version()$ssl_version) == TRUE)){
cat("openSSL backend for curl is required for the Windows version of this package, but it not
detected as being active. Please see the vignette on how to configure curl with openSSL for this
function to work. You can access the vignette with the following: vignette('rcatfish').")
}else{
my.search <- rcatfish_search(type = "Genus", query = c("Astatheros","Gasteropelecidae"),
taxon.history = TRUE, resolve = FALSE, sleep.time = 10)
}
#Perform a species search for two different taxa
if((.Platform$OS.type == "windows") & (grepl(pattern = "\\(OpenSSL",
curl::curl_version()$ssl_version) == TRUE)){
cat("openSSL backend for curl is required for the Windows version of this package, but it not
detected as being active. Please see the vignette on how to configure curl with openSSL for this
function to work. You can access the vignette with the following: vignette('rcatfish').")
}else{
my.search<-rcatfish_search(type = "Species", query = c("Ctenopharynx",
"Pseudocrenilabrus multicolor victoriae"), taxon.history = TRUE, resolve = FALSE,
sleep.time = 10)
}
# }
Run the code above in your browser using DataLab