Learn R Programming

rcatfish (version 1.0.2)

rcatfish_version: Retrieve the current version Number of the Eschmeyer's Catalog of Fishes Being Used

Description

Returns the current version of Catalog of Fishes being used in the R session

Usage

rcatfish_version()

Arguments

Value

Character Vector length of one with the Catalog of Fishes version

Author

Samuel R. Borstein

References

Fricke, R., Eschmeyer, W.N. & van der Laan, R. (Year Accessed). Eschmeyer's Catalog of Fishes: Genera, Species, References. https://researcharchive.calacademy.org/research/ichthyology/catalog/fishcatmain.asp.

Examples

Run this code
if (FALSE) { # interactive()
# \donttest{
#' my.version <- rcatfish_version()
# }
}

Run the code above in your browser using DataLab